/***************************************************************************
                          kflameconfig.cpp  -  description
                             -------------------
    begin                : Sat Dec 14 2002
    copyright            : (C) 2002 by Pedro J. Romero (Cronel)
    email                : pejro@millicom.com.ar
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <qradiobutton.h>
#include <qspinbox.h>
#include <qtoolbutton.h>
#include <qcheckbox.h>

#include <kglobal.h>
#include <kconfig.h>
#include <kmessagebox.h>
#include <kcolorbutton.h>
#include <klocale.h>
#include <ksqueezedtextlabel.h>
#include <kurlrequester.h>
#include <kstandarddirs.h>

#include "ktextconfig.h"
#include "kflameconfig.h"
#include "kaboutdlg.h"

KFlameConfig::KFlameConfig(QWidget *parent, const char *name ) : KFlameConfigUI(parent,name)
{
        m_text.setAutoDelete( true );
}

KFlameConfig::~KFlameConfig()
{
}

void KFlameConfig::slotAbout()
{
        KAboutDlg *dlg = new KAboutDlg(this);
        dlg->show();
}

void KFlameConfig::slotDefaults()
{
        using namespace defaults;
        if( !defaultMode.compare( "Twin Peaks" ) )
                radioTPMode->setChecked( true );
        else
                radioFlameMode->setChecked( true );

        urlPic->setURL( defaultPic );

        checkAutoCellSize->setChecked( defaultAutoCellSize );
        spinCellWidth->setValue( defaultCellWidth );
        spinCellHeight->setValue( defaultCellHeight );
        spinHotSpots->setValue( defaultHotSpots );
        spinFadeThreshold->setValue( defaultFadeThreshold );
        spinFadeAmount->setValue( defaultFadeAmount );
        cbutFlameColor->setColor( defaultFlameColor );

        m_text.clear();
        m_frames = defaultTextFrames;
        m_font = defaultTextFont;
        setTextLabel();
}

void KFlameConfig::accept()
{
        KConfig *cfg = KGlobal::config();
        KConfigGroupSaver save(cfg, "Settings" );

        cfg->writeEntry( "Mode", radioTPMode->isChecked() ? "Twin Peaks" : "Flame" );

        cfg->writeEntry( "Pic", urlPic->url() );

        cfg->writeEntry( "AutoCellSize", checkAutoCellSize->isChecked() );
        cfg->writeEntry( "CellWidth", spinCellWidth->value() );
        cfg->writeEntry( "CellHeight", spinCellHeight->value() );
        cfg->writeEntry( "HotSpots", spinHotSpots->value() );
        cfg->writeEntry( "FadeThreshold", spinFadeThreshold->value() );
        cfg->writeEntry( "FadeAmount", spinFadeAmount->value() );
        cfg->writeEntry( "FlameColor", cbutFlameColor->color() );

        cfg->writeEntry( "TextFrames", m_frames );
        cfg->writeEntry( "TextFont", m_font );
        cfg->writeEntry( "TextCount", m_text.count() );
        for(uint i=0;i < m_text.count(); i++)
                cfg->writeEntry( QString("Text_%1").arg(i), m_text.at(i)->toString() );
        cfg->sync();

        QDialog::accept();
}

void KFlameConfig::show()
{
        using namespace defaults;
        KConfig *cfg = KGlobal::config();
        KConfigGroupSaver save(cfg, "Settings" );
        uint i, count;
        QString str;
        KTextInfo *ti;

        QString mode = cfg->readEntry( "Mode", defaultMode );
        if( !mode.compare("Twin Peaks") )
                radioTPMode->setChecked( true );
        else
                radioFlameMode->setChecked( true );

        urlPic->setURL( cfg->readEntry( "Pic", defaultPic ) );
        
        checkAutoCellSize->setChecked( cfg->readBoolEntry( "AutoCellSize", defaultAutoCellSize ) );
        spinCellWidth->setValue( cfg->readNumEntry("CellWidth", defaultCellWidth ) );
        spinCellHeight->setValue( cfg->readNumEntry("CellHeight", defaultCellHeight ) );
        spinHotSpots->setValue( cfg->readNumEntry("HotSpots", defaultHotSpots ) );
        spinFadeThreshold->setValue( cfg->readNumEntry("FadeThreshold", defaultFadeThreshold ) );
        spinFadeAmount->setValue( cfg->readNumEntry("FadeAmount", defaultFadeAmount ) );
        cbutFlameColor->setColor( cfg->readColorEntry("FlameColor", &defaultFlameColor ) );

        m_frames = cfg->readNumEntry( "TextFrames", defaultTextFrames );
        m_font = cfg->readFontEntry( "TextFont", &defaultTextFont );
        count = cfg->readNumEntry( "TextCount", 0 );
        m_text.clear();
        for(i=0; i<count; i++ )
        {
                str = cfg->readEntry( QString("Text_%1").arg(i), "" );
                ti = new KTextInfo(str);
                m_text.append( ti );
        }
        setTextLabel();
        
        QDialog::show();
}

void KFlameConfig::slotSetupText()
{
        KTextConfig *dlg = new KTextConfig(this,0L);
        dlg->setData( m_text, m_frames, m_font );
        if( dlg->exec() == QDialog::Accepted )
        {
                m_text = dlg->textInfo();
                m_frames = dlg->frames();
                m_font = dlg->font();
                setTextLabel();
        }
        delete dlg;
}

void KFlameConfig::setTextLabel()
{
        QStringList list;
        if( m_text.count() == 0 )
                textLabel->setText( i18n("(None)") );
        else
        {
                for(uint i=0; i<m_text.count();i++ )
                        list.append( m_text.at(i)->m_text );
                QString str = list.join( "/" );
                textLabel->setText( str );
        }
}
