/***************************************************************************
                          ktextconfig.cpp  -  description
                             -------------------
    begin                : Sun Dec 15 2002
    copyright            : (C) 2002 by Pedro J. Romero (Cronel)
    email                : pejro@millicom.com.ar
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#include <qlist.h>
#include <qlistbox.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qspinbox.h>
#include <qlayout.h>

#include <kfontcombo.h>
#include <klocale.h>
   
#include "ktextconfig.h"

KTextConfig::KTextConfig(QWidget *parent, const char *name ) : KTextConfigUI(parent,name,true)
{
        layout->expand( TEXT_COUNT, 4 );

        QLabel *label;
        label = new QLabel( this, 0 );
        label->setText( i18n("Text") );
        label->setSizePolicy( QSizePolicy( QSizePolicy::Preferred, QSizePolicy::Fixed ) );
        layout->addWidget( label, 0, 0 );

        label = new QLabel( this, 0 );
        label->setText( i18n("Frame") );
        layout->addWidget( label, 0, 1 );

        label = new QLabel( this, 0 );
        label->setText( i18n("Cell X") );
        layout->addWidget( label, 0, 2 );

        label = new QLabel( this, 0 );
        label->setText( i18n("Cell Y") );
        layout->addWidget( label, 0, 3 );

        int i;
        QLineEdit *edit;
        QSpinBox *spin;
        for(i=1; i<TEXT_COUNT+1; i++ )
        {
                edit = new QLineEdit( this, 0 );
                layout->addWidget( edit, i, 0 );
                m_texts[i-1] = edit;

                spin = new QSpinBox( this, 0 );
                layout->addWidget( spin, i, 1 );
                spin->setMaxValue( 10000 );
                spin->setMinValue( -10000 );
                m_frames[i-1] = spin;
                
                spin = new QSpinBox( this, 0 );
                layout->addWidget( spin, i, 2 );
                spin->setMaxValue( 10000 );
                spin->setMinValue( -10000 );
                m_xPos[i-1] = spin;
                
                spin = new QSpinBox( this, 0 );
                layout->addWidget( spin, i, 3 );
                spin->setMaxValue( 10000 );
                spin->setMinValue( -10000 );
                m_yPos[i-1] = spin;
        }

        setTabOrder( (QWidget*)spinFrames, (QWidget*)comboFontName );
        setTabOrder( (QWidget*)comboFontName, (QWidget*)spinFontSize );
        QWidget *prev = spinFontSize;
        for(i=0;i<TEXT_COUNT;i++)
        {
                setTabOrder( prev, m_texts[i] );
                setTabOrder( m_texts[i], m_frames[i] );
                setTabOrder( m_frames[i], m_xPos[i] );
                setTabOrder( m_xPos[i], m_yPos[i] );
                prev = m_yPos[i];
        }
        setTabOrder( prev, (QWidget*)buttonOK );
        setTabOrder( (QWidget*)buttonOK, (QWidget*)buttonCancel );
}

KTextConfig::~KTextConfig()
{
}

void KTextConfig::setData( QList<KTextInfo> list, int frames, const QFont &font )
{
        int count, i;
        KTextInfo *ti;
        count = list.count() < TEXT_COUNT ? list.count() : TEXT_COUNT;
        for( i=0; i<count; i++ )
        {
                ti = list.at(i);
                m_texts[i]->setText( ti->m_text );
                m_frames[i]->setValue( ti->m_frame );
                m_xPos[i]->setValue( ti->m_x );
                m_yPos[i]->setValue( ti->m_y );
        }
        spinFrames->setValue( frames );
        spinFontSize->setValue( font.pointSize() );
        /* It's unbelievable that you have to do this to set the
        combobox to a known value; or am I missing something?? */
        comboFontName->setCurrentItem( 0 );
        QListBox *lbox = comboFontName->listBox();
        for(i=0;(uint)i<lbox->count();i++ )
        {
                if( !font.family().compare( lbox->text(i) ) )
                {
                        comboFontName->setCurrentItem( i );
                        break;
                }
        }
}

QList<KTextInfo> KTextConfig::textInfo()
{
        QList<KTextInfo> list;
        int i;

        list.clear();
        for( i=0 ; i< TEXT_COUNT; i++ )
        {
                if( m_texts[i]->text().isEmpty() )
                        continue;
                list.append( new KTextInfo(
                        m_texts[i]->text(),
                        m_frames[i]->value(),
                        m_xPos[i]->value(),
                        m_yPos[i]->value(),
                        255
                        ) );
        }
        return list;
}

int KTextConfig::frames()
{
        return spinFrames->value();
}

QFont KTextConfig::font()
{
        QFont f(
                comboFontName->currentText(),
                spinFontSize->value() );
        return f;
}

int KTextConfig::exec()
{
        return QDialog::exec();
}

